==> western-world-3.0.66.tgz: package/src/western-world.utils.js <==
import {
  backgroundsArr,
  othersFiles,
  languageSvgStyles,
  myFlagSvgStyles,
  enemyFlagSvgStyles,
  flagStarsStyles,
} from './western-world.utils.constants';
import {
  // createSVG,
  getPathByCell,
  getImageByUrl,
  getFlagsArray,
  // getSvgPathBorder,
  buildImageForCanvasFromHtmlStr,
  getMaxSide,
} from './western-world.utils.helpers';

let newSvgImagesResolve;
let otherSvgImagesResolve;

export const images = {
  svgTags: {},
  svgImagesForCanvas: {}, // map HTMLImageElement for canvas;
  avatarsMapForCanvas: {}, // map HTMLImageElement for canvas;
  resolver: {
    all: Promise.all([
      new Promise((resolve) => (newSvgImagesResolve = resolve)),
      new Promise((resolve) => (otherSvgImagesResolve = resolve)),
    ]),
  },
  allImagesProgress: {
    data: {
      all: 0,
      loaded: 0,
    },
    resetLoadingImage() {
      this.data.all = 0;
      this.data.loaded = 0;
    },
    startLoadingImage() {
      this.data.all++;
    },
    endLoadingImage() {
      this.data.loaded++;
    },
  },
};

export const buildNewSvgImages = ({ imagesBaseUrl, allCells, language }) => {
  const parser = new DOMParser();
  return Promise.all(
    allCells
      .filter((cell) => cell.id)
      .map((cell) => {
        images.allImagesProgress.startLoadingImage();
        return (
          fetch(`${imagesBaseUrl || ''}/assets/images/svg/${cell.animatedImage}.svg`)
            .then((data) => data.text())
            .then((html) => {
              let newHtml = html.replace(/\.st([0-9]{1,3})/g, `.${cell.animatedImage}_st$1`);
              newHtml = newHtml.replace(/\"st([0-9]{1,3})/g, `"${cell.animatedImage}_st$1`);
              newHtml = newHtml.replace(/SVGID_([0-9]{1,3})_/g, `${cell.animatedImage}_SVGID_$1_`);

              // get svg image from file and apply offsets;
              const doc = parser.parseFromString(newHtml, 'image/svg+xml');

              const svgEl = doc.querySelector('svg');
              const maxMainSvgViewBox = svgEl.viewBox.baseVal.width;
              svgEl.classList.add(cell.animatedImage);

              const styleElement = svgEl.querySelector('svg > style');
              const styleSvg = `
                ${languageSvgStyles}
                use.use-mask {
                  stroke-width: 200px;
                  stroke: black;
                  fill: white;
                }
                use.use-border {
                  stroke-width: 100px;
                  stroke: white;
                  fill: black;
                }
                use.use-additional-mask {
                  fill: white;
                }
              `;
              styleElement.insertAdjacentHTML('beforeend', styleSvg);

              // create new <g> and move all content to it to apply mask;
              const gElement = document.createElementNS('http://www.w3.org/2000/svg', 'g');
              gElement.setAttribute('mask', `url(#${cell.id})`);
              gElement.setAttribute('class', language);
              const allSvgImageContent = svgEl.querySelectorAll('svg > *:not(style)');
              [...allSvgImageContent].forEach((el) => gElement.appendChild(el));

              // create use border path;
              const svgUseBorderElement = document.createElementNS('http://www.w3.org/2000/svg', 'use');
              svgUseBorderElement.setAttribute('xlink:href', '#path-border');
              svgUseBorderElement.setAttribute('class', 'use-border');

              const maxCellSize = getMaxSide(cell);
              const cellPath = getPathByCell(cell, maxCellSize, maxMainSvgViewBox);
              const mask = `
                <mask id="${cell.id}">
                  <use xlink:href="#path-border" class="use-mask"></use>
                  <use xlink:href="#additional-mask" class="use-additional-mask"></use>
                </mask>
              `;
              const defsElement = document.createElementNS('http://www.w3.org/2000/svg', 'defs');
              defsElement.innerHTML = `
                ${cellPath}
                ${mask}
              `;
              svgEl.appendChild(defsElement);
              svgEl.appendChild(svgUseBorderElement);
              svgEl.appendChild(gElement);

              /* add additional elements to mask for cells such as: 2 */
              let additionalMask = '';
              // TODO....;
              /*const additionalMaskEl = svgEl.querySelector('#additional-mask');
              if (additionalMaskEl) {
                const svgAdditionalMaskEl = createSVG();
                const additionalMaskElClone = additionalMaskEl.cloneNode();
                additionalMaskElClone.style.fill = 'white';
                additionalMaskElClone.style.stroke = 'white';
                svgAdditionalMaskEl.appendChild(additionalMaskElClone);
                svgAdditionalMaskEl.setAttribute('viewBox', svgEl.getAttribute('viewBox'));
                additionalMask = svgAdditionalMaskEl.outerHTML;
              }*/

              /*const pathMaskStr = getPathByCell(cell, PATH_STROKE_WIDTH_FOR_MASK);
              const svgPathBorder = getSvgPathBorder(cell, max, max, PATH_STROKE_WIDTH, PATH_STROKE_WIDTH_FOR_MASK);

              const str = `
                  <style>svg {overflow: visible} ${languageSvgStyles}</style>
                  <mask id="${cell.id}">
                    <svg xmlns:xlink="http://www.w3.org/1999/xlink" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 ${max} ${max}">
                      ${pathMaskStr}
                      ${additionalMask}
                    </svg>
                  </mask>
                  ${svgPathBorder.outerHTML}
                  <svg xmlns:xlink="http://www.w3.org/1999/xlink" xmlns="http://www.w3.org/2000/svg" mask="url(#${cell.id})" class="${language}">
                    ${svgEl.outerHTML}
                  </svg>
                `;
              const svgContainerMain = createSVG();
              svgContainerMain.setAttribute('viewBox', `0 0 ${max} ${max}`);
              svgContainerMain.innerHTML = str;
              */

              //images.svgTags[cell.animatedImage] = svgEl.outerHTML;
              //images.svgTags[`with_mask_${cell.id}`] = svgContainerMain.outerHTML;

              images.svgTags[cell.animatedImage] = svgEl.outerHTML;
              // images.svgTags[cell.id] = svgEl.outerHTML;

              //return buildImageForCanvasFromHtmlStr(svgContainerMain.outerHTML)
              return buildImageForCanvasFromHtmlStr(svgEl.outerHTML)
                .then((img) => (images.svgImagesForCanvas[cell.id] = img))
                .then(() => images.allImagesProgress.endLoadingImage());
            })
            // tslint:disable-next-line:no-console
            .catch(console.log)
        );
      })
  ).then(newSvgImagesResolve);
};

export const parseAndSaveToObjectOtherSvgFile = ({ html, svgStyles, language, propertyName }) => {
  const parser = new DOMParser();

  const doc = parser.parseFromString(html, 'image/svg+xml');
  const svgEl = doc.querySelector('svg');
  const str = `
    <svg xmlns:xlink="http://www.w3.org/1999/xlink" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 10000 10000">
      <style>svg {overflow: visible} ${svgStyles}</style>
      <svg xmlns:xlink="http://www.w3.org/1999/xlink" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 10000 10000" class="${language}">
        ${svgEl.outerHTML}
      </svg>
    </svg>
  `;
  images.svgTags[propertyName] = str;
  return buildImageForCanvasFromHtmlStr(str);
};

export const buildOtherSvgImages = ({ language, imagesBaseUrl }) => {
  return Promise.all(
    othersFiles.map((fileName) => {
      images.allImagesProgress.startLoadingImage();
      return fetch(`${imagesBaseUrl || ''}/assets/images/svg/others/${fileName}`)
        .then((data) => data.text())
        .then((html) => {
          if (fileName === 'flag.svg') {
            return Promise.all(
              [...getFlagsArray('my'), ...getFlagsArray('enemy')].map((el) => {
                return parseAndSaveToObjectOtherSvgFile({
                  html,
                  svgStyles: `${el.prefix === 'my' ? myFlagSvgStyles : enemyFlagSvgStyles} ${
                    flagStarsStyles[el.index]
                  }`,
                  language,
                  propertyName: el.name,
                }).then((img) => (images.svgImagesForCanvas[el.name] = img));
              })
            ).then(() => images.allImagesProgress.endLoadingImage());
          }
          return parseAndSaveToObjectOtherSvgFile({
            html,
            svgStyles: languageSvgStyles,
            language,
            propertyName: fileName,
          })
            .then((img) => (images.svgImagesForCanvas[fileName] = img))
            .then(() => images.allImagesProgress.endLoadingImage());
        });
    })
  ).then(otherSvgImagesResolve);
};

export const drawBackgrounds = ({ ctx, BACKGROUND_X, BACKGROUND_Y, BACKGROUND_WIDTH, BACKGROUND_HEIGHT }) => {
  backgroundsArr.forEach((fileName) =>
    ctx.drawImage(images.svgImagesForCanvas[fileName], BACKGROUND_X, BACKGROUND_Y, BACKGROUND_WIDTH, BACKGROUND_HEIGHT)
  );
};

export const drawBackgroundTopElements = ({ ctx, BACKGROUND_X, BACKGROUND_Y, BACKGROUND_WIDTH, BACKGROUND_HEIGHT }) => {
  ctx.drawImage(
    images.svgImagesForCanvas['background-top-elements.svg'],
    BACKGROUND_X,
    BACKGROUND_Y,
    BACKGROUND_WIDTH,
    BACKGROUND_HEIGHT
  );
};

export const drawNewAdditionalStuff = ({ ctx, SIZE_X_QUALITY, PADDING_LEFT, PADDING_TOP }) => {
  ctx.drawImage(
    images.svgImagesForCanvas['colony-arrows.svg'],
    295 * SIZE_X_QUALITY + PADDING_LEFT,
    145 * SIZE_X_QUALITY + PADDING_TOP,
    1025 * SIZE_X_QUALITY,
    1025 * SIZE_X_QUALITY
  );
};

export const drawFlags = ({ allCells, ctx, game, myIdKey, SIZE_X_QUALITY, PADDING_LEFT, PADDING_TOP }) => {
  const myPlayer = game.players[myIdKey];
  const allMyCompanies = myPlayer?.firms;
  const allEnemyCompanies = game.players.order.reduce((previousValue, playerIdKey) => {
    if (playerIdKey === myPlayer?.user?.id_key) {
      return previousValue;
    }
    game.players[playerIdKey].firms.forEach((firmId) => {
      previousValue[firmId] = playerIdKey;
    });
    return previousValue;
  }, {});
  allCells
    .filter((cell) => cell.id)
    .forEach((cell) => {
      const flagX = cell.flag ? cell.flag.x : cell.location.x1 + (cell.location.x2 - cell.location.x1) / 2;
      const flagY = cell.flag ? cell.flag.y : cell.location.y1;
      let flag;
      let avatar;
      if (allEnemyCompanies[cell.id]) {
        flag = images.svgImagesForCanvas[`enemy-flag-stars-${game.stocks[cell.id].stars}`];
        avatar = images.avatarsMapForCanvas[allEnemyCompanies[cell.id]];
      }
      if (allMyCompanies?.includes(cell.id)) {
        flag = images.svgImagesForCanvas[`my-flag-stars-${game.stocks[cell.id].stars}`];
        avatar = images.avatarsMapForCanvas[myPlayer.user.id_key];
      }
      if (!flag || !avatar) {
        return;
      }
      ctx.drawImage(
        flag,
        (cell.location.x1 + flagX - 53) * SIZE_X_QUALITY + PADDING_LEFT,
        (cell.location.y1 + flagY - 60) * SIZE_X_QUALITY + PADDING_TOP,
        64 * SIZE_X_QUALITY,
        64 * SIZE_X_QUALITY
      );
      ctx.drawImage(
        avatar,
        (cell.location.x1 + flagX - 22.5) * SIZE_X_QUALITY + PADDING_LEFT,
        (cell.location.y1 + flagY - 35) * SIZE_X_QUALITY + PADDING_TOP,
        15 * SIZE_X_QUALITY,
        15 * SIZE_X_QUALITY
      );
    });
};

export const drawAllNewCells = ({ allCells, ctx, SIZE_X_QUALITY, PADDING_LEFT, PADDING_TOP }) => {
  allCells
    .filter((cell) => cell.id)
    .forEach((cell) => {
      const max = getMaxSide(cell);
      ctx.drawImage(
        images.svgImagesForCanvas[cell.id],
        cell.location.x1 * SIZE_X_QUALITY + PADDING_LEFT,
        cell.location.y1 * SIZE_X_QUALITY + PADDING_TOP,
        max * SIZE_X_QUALITY,
        max * SIZE_X_QUALITY
      );
    });
};

export const buildPlayerAvatars = ({ avatars, imagesBaseUrl }) => {
  if (!avatars) {
    return Promise.reject();
  }
  return Promise.all(
    avatars.map(({ icon }) => getImageByUrl(`${imagesBaseUrl || ''}/assets/images/avatars/${icon}.png`))
  ).then((data) => {
    data.forEach((image, index) => {
      images.avatarsMapForCanvas[avatars[index].id_key] = image;
    });
  });
};

==> western-world-3.0.67.tgz: package/src/western-world.utils.js <==
import {
  backgroundsArr,
  othersFiles,
  languageSvgStyles,
  myFlagSvgStyles,
  enemyFlagSvgStyles,
  flagStarsStyles,
} from './western-world.utils.constants';
import {
  // createSVG,
  getPathByCell,
  getImageByUrl,
  getFlagsArray,
  // getSvgPathBorder,
  buildImageForCanvasFromHtmlStr,
  getMaxSide,
} from './western-world.utils.helpers';

let newSvgImagesResolve;
let otherSvgImagesResolve;

export const images = {
  svgTags: {},
  svgImagesForCanvas: {}, // map HTMLImageElement for canvas;
  avatarsMapForCanvas: {}, // map HTMLImageElement for canvas;
  resolver: {
    all: Promise.all([
      new Promise((resolve) => (newSvgImagesResolve = resolve)),
      new Promise((resolve) => (otherSvgImagesResolve = resolve)),
    ]),
  },
  allImagesProgress: {
    data: {
      all: 0,
      loaded: 0,
    },
    resetLoadingImage() {
      this.data.all = 0;
      this.data.loaded = 0;
    },
    startLoadingImage() {
      this.data.all++;
    },
    endLoadingImage() {
      this.data.loaded++;
    },
  },
};

export const buildNewSvgImages = ({ imagesBaseUrl, allCells, language }) => {
  const parser = new DOMParser();
  return Promise.all(
    allCells
      .filter((cell) => cell.id)
      .map((cell) => {
        images.allImagesProgress.startLoadingImage();
        return (
          fetch(`${imagesBaseUrl || ''}/assets/images/svg/${cell.animatedImage}.svg`)
            .then((data) => data.text())
            .then((html) => {
              let newHtml = html.replace(/\.st([0-9]{1,3})/g, `.${cell.animatedImage}_st$1`);
              newHtml = newHtml.replace(/\"st([0-9]{1,3})/g, `"${cell.animatedImage}_st$1`);
              newHtml = newHtml.replace(/SVGID_([0-9]{1,3})_/g, `${cell.animatedImage}_SVGID_$1_`);

              // get svg image from file and apply offsets;
              const doc = parser.parseFromString(newHtml, 'image/svg+xml');

              const svgEl = doc.querySelector('svg');
              const maxMainSvgViewBox = svgEl.viewBox.baseVal.width;
              svgEl.classList.add(cell.animatedImage);

              const styleElement = svgEl.querySelector('svg > style');
              const styleSvg = `
                ${languageSvgStyles}
                use.use-mask {
                  stroke-width: 200px;
                  stroke: black;
                  fill: white;
                }
                use.use-border {
                  stroke-width: 100px;
                  stroke: white;
                  fill: black;
                }
              `;
              styleElement.insertAdjacentHTML('beforeend', styleSvg);

              // create new <g> and move all content to it to apply mask;
              const gElement = document.createElementNS('http://www.w3.org/2000/svg', 'g');
              gElement.setAttribute('mask', `url(#${cell.id})`);
              gElement.setAttribute('class', language);
              const allSvgImageContent = svgEl.querySelectorAll('svg > *:not(style)');
              [...allSvgImageContent].forEach((el) => gElement.appendChild(el));

              // create use border path;
              const svgUseBorderElement = document.createElementNS('http://www.w3.org/2000/svg', 'use');
              svgUseBorderElement.setAttribute('xlink:href', '#path-border');
              svgUseBorderElement.setAttribute('class', 'use-border');

              const maxCellSize = getMaxSide(cell);
              const cellPath = getPathByCell(cell, maxCellSize, maxMainSvgViewBox);
              const mask = `
                <mask id="${cell.id}">
                  <use xlink:href="#path-border" class="use-mask"></use>
                  <use xlink:href="#additional-mask">
                    <style>path {fill: white}</style>
                  </use>
                </mask>
              `;
              const defsElement = document.createElementNS('http://www.w3.org/2000/svg', 'defs');
              defsElement.innerHTML = `
                ${cellPath}
                ${mask}
              `;
              svgEl.appendChild(defsElement);
              svgEl.appendChild(svgUseBorderElement);
              svgEl.appendChild(gElement);

              /* add additional elements to mask for cells such as: 2 */
              let additionalMask = '';
              // TODO....;
              /*const additionalMaskEl = svgEl.querySelector('#additional-mask');
              if (additionalMaskEl) {
                const svgAdditionalMaskEl = createSVG();
                const additionalMaskElClone = additionalMaskEl.cloneNode();
                additionalMaskElClone.style.fill = 'white';
                additionalMaskElClone.style.stroke = 'white';
                svgAdditionalMaskEl.appendChild(additionalMaskElClone);
                svgAdditionalMaskEl.setAttribute('viewBox', svgEl.getAttribute('viewBox'));
                additionalMask = svgAdditionalMaskEl.outerHTML;
              }*/

              /*const pathMaskStr = getPathByCell(cell, PATH_STROKE_WIDTH_FOR_MASK);
              const svgPathBorder = getSvgPathBorder(cell, max, max, PATH_STROKE_WIDTH, PATH_STROKE_WIDTH_FOR_MASK);

              const str = `
                  <style>svg {overflow: visible} ${languageSvgStyles}</style>
                  <mask id="${cell.id}">
                    <svg xmlns:xlink="http://www.w3.org/1999/xlink" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 ${max} ${max}">
                      ${pathMaskStr}
                      ${additionalMask}
                    </svg>
                  </mask>
                  ${svgPathBorder.outerHTML}
                  <svg xmlns:xlink="http://www.w3.org/1999/xlink" xmlns="http://www.w3.org/2000/svg" mask="url(#${cell.id})" class="${language}">
                    ${svgEl.outerHTML}
                  </svg>
                `;
              const svgContainerMain = createSVG();
              svgContainerMain.setAttribute('viewBox', `0 0 ${max} ${max}`);
              svgContainerMain.innerHTML = str;
              */

              //images.svgTags[cell.animatedImage] = svgEl.outerHTML;
              //images.svgTags[`with_mask_${cell.id}`] = svgContainerMain.outerHTML;

              images.svgTags[cell.animatedImage] = svgEl.outerHTML;
              // images.svgTags[cell.id] = svgEl.outerHTML;

              //return buildImageForCanvasFromHtmlStr(svgContainerMain.outerHTML)
              return buildImageForCanvasFromHtmlStr(svgEl.outerHTML)
                .then((img) => (images.svgImagesForCanvas[cell.id] = img))
                .then(() => images.allImagesProgress.endLoadingImage());
            })
            // tslint:disable-next-line:no-console
            .catch(console.log)
        );
      })
  ).then(newSvgImagesResolve);
};

export const parseAndSaveToObjectOtherSvgFile = ({ html, svgStyles, language, propertyName }) => {
  const parser = new DOMParser();

  const doc = parser.parseFromString(html, 'image/svg+xml');
  const svgEl = doc.querySelector('svg');
  const str = `
    <svg xmlns:xlink="http://www.w3.org/1999/xlink" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 10000 10000">
      <style>svg {overflow: visible} ${svgStyles}</style>
      <svg xmlns:xlink="http://www.w3.org/1999/xlink" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 10000 10000" class="${language}">
        ${svgEl.outerHTML}
      </svg>
    </svg>
  `;
  images.svgTags[propertyName] = str;
  return buildImageForCanvasFromHtmlStr(str);
};

export const buildOtherSvgImages = ({ language, imagesBaseUrl }) => {
  return Promise.all(
    othersFiles.map((fileName) => {
      images.allImagesProgress.startLoadingImage();
      return fetch(`${imagesBaseUrl || ''}/assets/images/svg/others/${fileName}`)
        .then((data) => data.text())
        .then((html) => {
          if (fileName === 'flag.svg') {
            return Promise.all(
              [...getFlagsArray('my'), ...getFlagsArray('enemy')].map((el) => {
                return parseAndSaveToObjectOtherSvgFile({
                  html,
                  svgStyles: `${el.prefix === 'my' ? myFlagSvgStyles : enemyFlagSvgStyles} ${
                    flagStarsStyles[el.index]
                  }`,
                  language,
                  propertyName: el.name,
                }).then((img) => (images.svgImagesForCanvas[el.name] = img));
              })
            ).then(() => images.allImagesProgress.endLoadingImage());
          }
          return parseAndSaveToObjectOtherSvgFile({
            html,
            svgStyles: languageSvgStyles,
            language,
            propertyName: fileName,
          })
            .then((img) => (images.svgImagesForCanvas[fileName] = img))
            .then(() => images.allImagesProgress.endLoadingImage());
        });
    })
  ).then(otherSvgImagesResolve);
};

export const drawBackgrounds = ({ ctx, BACKGROUND_X, BACKGROUND_Y, BACKGROUND_WIDTH, BACKGROUND_HEIGHT }) => {
  backgroundsArr.forEach((fileName) =>
    ctx.drawImage(images.svgImagesForCanvas[fileName], BACKGROUND_X, BACKGROUND_Y, BACKGROUND_WIDTH, BACKGROUND_HEIGHT)
  );
};

export const drawBackgroundTopElements = ({ ctx, BACKGROUND_X, BACKGROUND_Y, BACKGROUND_WIDTH, BACKGROUND_HEIGHT }) => {
  ctx.drawImage(
    images.svgImagesForCanvas['background-top-elements.svg'],
    BACKGROUND_X,
    BACKGROUND_Y,
    BACKGROUND_WIDTH,
    BACKGROUND_HEIGHT
  );
};

export const drawNewAdditionalStuff = ({ ctx, SIZE_X_QUALITY, PADDING_LEFT, PADDING_TOP }) => {
  ctx.drawImage(
    images.svgImagesForCanvas['colony-arrows.svg'],
    295 * SIZE_X_QUALITY + PADDING_LEFT,
    145 * SIZE_X_QUALITY + PADDING_TOP,
    1025 * SIZE_X_QUALITY,
    1025 * SIZE_X_QUALITY
  );
};

export const drawFlags = ({ allCells, ctx, game, myIdKey, SIZE_X_QUALITY, PADDING_LEFT, PADDING_TOP }) => {
  const myPlayer = game.players[myIdKey];
  const allMyCompanies = myPlayer?.firms;
  const allEnemyCompanies = game.players.order.reduce((previousValue, playerIdKey) => {
    if (playerIdKey === myPlayer?.user?.id_key) {
      return previousValue;
    }
    game.players[playerIdKey].firms.forEach((firmId) => {
      previousValue[firmId] = playerIdKey;
    });
    return previousValue;
  }, {});
  allCells
    .filter((cell) => cell.id)
    .forEach((cell) => {
      const flagX = cell.flag ? cell.flag.x : cell.location.x1 + (cell.location.x2 - cell.location.x1) / 2;
      const flagY = cell.flag ? cell.flag.y : cell.location.y1;
      let flag;
      let avatar;
      if (allEnemyCompanies[cell.id]) {
        flag = images.svgImagesForCanvas[`enemy-flag-stars-${game.stocks[cell.id].stars}`];
        avatar = images.avatarsMapForCanvas[allEnemyCompanies[cell.id]];
      }
      if (allMyCompanies?.includes(cell.id)) {
        flag = images.svgImagesForCanvas[`my-flag-stars-${game.stocks[cell.id].stars}`];
        avatar = images.avatarsMapForCanvas[myPlayer.user.id_key];
      }
      if (!flag || !avatar) {
        return;
      }
      ctx.drawImage(
        flag,
        (cell.location.x1 + flagX - 53) * SIZE_X_QUALITY + PADDING_LEFT,
        (cell.location.y1 + flagY - 60) * SIZE_X_QUALITY + PADDING_TOP,
        64 * SIZE_X_QUALITY,
        64 * SIZE_X_QUALITY
      );
      ctx.drawImage(
        avatar,
        (cell.location.x1 + flagX - 22.5) * SIZE_X_QUALITY + PADDING_LEFT,
        (cell.location.y1 + flagY - 35) * SIZE_X_QUALITY + PADDING_TOP,
        15 * SIZE_X_QUALITY,
        15 * SIZE_X_QUALITY
      );
    });
};

export const drawAllNewCells = ({ allCells, ctx, SIZE_X_QUALITY, PADDING_LEFT, PADDING_TOP }) => {
  allCells
    .filter((cell) => cell.id)
    .forEach((cell) => {
      const max = getMaxSide(cell);
      ctx.drawImage(
        images.svgImagesForCanvas[cell.id],
        cell.location.x1 * SIZE_X_QUALITY + PADDING_LEFT,
        cell.location.y1 * SIZE_X_QUALITY + PADDING_TOP,
        max * SIZE_X_QUALITY,
        max * SIZE_X_QUALITY
      );
    });
};

export const buildPlayerAvatars = ({ avatars, imagesBaseUrl }) => {
  if (!avatars) {
    return Promise.reject();
  }
  return Promise.all(
    avatars.map(({ icon }) => getImageByUrl(`${imagesBaseUrl || ''}/assets/images/avatars/${icon}.png`))
  ).then((data) => {
    data.forEach((image, index) => {
      images.avatarsMapForCanvas[avatars[index].id_key] = image;
    });
  });
};
